/**
 * The MIT License (MIT)
 *
 * Copyright (c) 2014-2016 Marc de Verdelhan & respective authors (see AUTHORS)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
 * the Software, and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 * COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package eu.verdelhan.ta4j.indicators.trackers;

import eu.verdelhan.ta4j.Decimal;
import eu.verdelhan.ta4j.TimeSeries;
import eu.verdelhan.ta4j.indicators.CachedIndicator;
import eu.verdelhan.ta4j.indicators.helpers.AverageTrueRangeIndicator;
import eu.verdelhan.ta4j.indicators.helpers.LowestValueIndicator;
import eu.verdelhan.ta4j.indicators.simple.MinPriceIndicator;

/**
 * The Chandelier Exit (short) Indicator.
 * @see http://stockcharts.com/school/doku.php?id=chart_school:technical_indicators:chandelier_exit
 */
public class ChandelierExitShortIndicator extends CachedIndicator<Decimal> {

    private final LowestValueIndicator low;
    
    private final AverageTrueRangeIndicator atr;
    
    private final Decimal k;

    /**
     * Constructor.
     * @param series the time series
     */
    public ChandelierExitShortIndicator(TimeSeries series) {
        this(series, 22, Decimal.THREE);
    }
    
    /**
     * Constructor.
     * @param series the time series
     * @param timeFrame the time frame (usually 22)
     * @param k the K multiplier for ATR (usually 3.0)
     */
    public ChandelierExitShortIndicator(TimeSeries series, int timeFrame, Decimal k) {
        super(series);
        low = new LowestValueIndicator(new MinPriceIndicator(series), timeFrame);
        atr = new AverageTrueRangeIndicator(series, timeFrame);
        this.k = k;
    }

    @Override
    protected Decimal calculate(int index) {
        return low.getValue(index).plus(atr.getValue(index).multipliedBy(k));
    }
}
